Create a landscape with very dense vegetation
Source:R/create_landscape_dense.R
create_landscape_dense.RdCreates a landscape with dense vegetation cover using random distribution.
This is a specialized wrapper around create_landscape_random
with high vegetation proportions.
Value
A landscape object with pattern "dense" containing
- data
SpatRaster with binary values (0 = bare ground, 1 = vegetation)
- pattern
Character string "dense"
- params
List of all input parameters used to generate the landscape
See also
Other landscape creation:
create_landscape(),
create_landscape_bands(),
create_landscape_bare(),
create_landscape_clustered(),
create_landscape_diffuse(),
create_landscape_fingers(),
create_landscape_gaps(),
create_landscape_labyrinth(),
create_landscape_random(),
create_landscape_sharp(),
create_landscape_spots(),
create_landscapes()